/*
 *  Copyright (c) 2007 Cyrille Berger <cberger@cberger.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#include "kis_meta_data_io_backend.h"

#ifdef Q_CC_MSVC
#include <iso646.h>
#endif

using namespace KisMetaData;


struct IOBackendRegistry::Private {
    static IOBackendRegistry* s_instance;
};

IOBackendRegistry* IOBackendRegistry::Private::s_instance = 0;

IOBackendRegistry::IOBackendRegistry() : d(new Private)
{
    
}

IOBackendRegistry* IOBackendRegistry::instance()
{
    if(not Private::s_instance)
    {
       Private::s_instance = new IOBackendRegistry;
    }
    return Private::s_instance;
}
